@@ -220,8 +220,15 @@ parse_ranges <- function(page_range, quietly = FALSE) {
   splitted_df <- tibble::new_tibble(list(page_range = page_range), 
                                     nrow = nrow) %>% 
     mutate(id = 1:n(),
-           splitted = stringr::str_split(page_range, ",|\\+")) %>% 
-    tidyr::unnest()
+           splitted = stringr::str_split(page_range, ",|\\+"))
+  
+  if (tidyr_new_interface()) {
+    splitted_df <- splitted_df %>% 
+      tidyr::unnest(cols = c("splitted"))
+  } else {
+    splitted_df <- splitted_df %>% 
+      tidyr::unnest()
+  }
   
   # detect roman numerals which are occasionally used for introduction sections
   roman_chars <- str_detect(splitted_df$splitted, "x|i|v|X|I|V")
