@@ -19,7 +19,8 @@ footnotes_in_body <- "testfiles/footnotes-in-body.xml" %>%
 # tests -----
 test_that("Input data is checked", {
   expect_error(jst_get_footnotes("my_path.txt"))
-  expect_error(jst_get_footnotes("testfiles/standard_book.xml"), "You are using")
+  expect_error(jst_get_footnotes("testfiles/standard_book.xml"), 
+               class = "article_function_for_book")
 })
 
 test_that("class is correct", {
